@@ -25,13 +25,13 @@ from .conftest import ENV_ID, TEST_ADAPTERS
 
 @pytest.mark.parametrize("adapter", TEST_ADAPTERS)
 def test_pathy_is_path_instance(with_adapter: str) -> None:
-    blob = Pathy("gs://fake/blob")
+    blob = Pathy(f"{with_adapter}://fake/blob")
     assert isinstance(blob, Path)
 
 
 @pytest.mark.parametrize("adapter", TEST_ADAPTERS)
 def test_pathy_fluid(with_adapter: str, bucket: str) -> None:
-    path: FluidPath = Pathy.fluid(f"gs://{bucket}/{ENV_ID}/fake-key")
+    path: FluidPath = Pathy.fluid(f"{with_adapter}://{bucket}/{ENV_ID}/fake-key")
     assert isinstance(path, Pathy)
     path = Pathy.fluid("foo/bar.txt")
     assert isinstance(path, BasePath)
@@ -98,10 +98,10 @@ def test_pathy_stat(with_adapter: str, bucket: str) -> None:
 
 @pytest.mark.parametrize("adapter", TEST_ADAPTERS)
 def test_pathy_resolve(with_adapter: str, bucket: str) -> None:
-    path = Pathy(f"gs://{bucket}/{ENV_ID}/fake-key")
+    path = Pathy(f"{with_adapter}://{bucket}/{ENV_ID}/fake-key")
     assert path.resolve() == path
-    path = Pathy(f"gs://{bucket}/{ENV_ID}/dir/../fake-key")
-    assert path.resolve() == Pathy(f"gs://{bucket}/{ENV_ID}/fake-key")
+    path = Pathy(f"{with_adapter}://{bucket}/{ENV_ID}/dir/../fake-key")
+    assert path.resolve() == Pathy(f"{with_adapter}://{bucket}/{ENV_ID}/fake-key")
 
 
 @pytest.mark.parametrize("adapter", TEST_ADAPTERS)
@@ -116,6 +116,7 @@ def test_pathy_exists(with_adapter: str, bucket: str) -> None:
     assert Pathy(f"{with_adapter}://{invalid_bucket}/foo.blob").exists() is False
     # valid bucket with invalid object
     assert Pathy(f"{with_adapter}://{bucket}/not_found_lol_nice.txt").exists() is False
+    assert Pathy(f"{with_adapter}://{bucket}/@^@^#$%@#$.txt").exists() is False
 
     path = Pathy(f"{with_adapter}://{bucket}/{ENV_ID}/directory/foo.txt")
     path.write_text("---")
@@ -155,6 +156,12 @@ def test_pathy_glob(with_adapter: str, bucket: str) -> None:
         root / "1/dir/file.txt",
     ]
 
+    bad_root = Pathy(f"{with_adapter}://{bucket}-bad-name")
+    assert list(bad_root.glob("*.txt")) == []
+
+    bad_name = root / "@#$%@^@%@#@#$.glob"
+    assert list(bad_name.glob("*.glob")) == []
+
 
 @pytest.mark.parametrize("adapter", TEST_ADAPTERS)
 def test_pathy_unlink_path(with_adapter: str, bucket: str) -> None:
@@ -199,9 +206,9 @@ def test_pathy_iterdir(with_adapter: str, bucket: str) -> None:
         path = root / f"{i}.file"
         path.write_text("---")
 
-    # 1 file in a subfolder
-    path = root / "sub/file.txt"
-    path.write_text("---")
+    # 2 files in a subfolder
+    (root / "sub/file.txt").write_text("---")
+    (root / "sub/file2.txt").write_text("---")
 
     check = sorted(root.iterdir())
     assert check == [
