@@ -168,16 +168,9 @@ class BucketClientS3(BucketClient):
         except (ClientError, ParamValidationError):
             raise FileNotFoundError(f"Bucket {path.root} does not exist!")
 
-    def list_buckets(  # type:ignore[override]
-        self, **kwargs: Dict[str, Any]
-    ) -> Generator[S3NativeBucket, None, None]:
-        native_buckets = self.client.list_buckets(**kwargs)["Buckets"]
-        results = (BucketS3(n["Name"], self.client, n) for n in native_buckets)
-        return results
-
     def scandir(  # type:ignore[override]
         self,
-        path: Optional[PurePathy] = None,
+        path: PurePathy,
         prefix: Optional[str] = None,
         delimiter: Optional[str] = None,
     ) -> PathyScanDir:
@@ -215,7 +208,7 @@ class ScanDirS3(PathyScanDir):
     def __init__(
         self,
         client: BucketClient,
-        path: Optional[PurePathy] = None,
+        path: PurePathy,
         prefix: Optional[str] = None,
         delimiter: Optional[str] = None,
         page_size: Optional[int] = None,
@@ -224,11 +217,6 @@ class ScanDirS3(PathyScanDir):
         self._page_size = page_size
 
     def scandir(self) -> Generator[BucketEntryS3, None, None]:
-        if self._path is None or not self._path.root:
-            s3_bucket: BucketS3
-            for s3_bucket in self._client.list_buckets():
-                yield BucketEntryS3(s3_bucket.name, is_dir=True, raw=None)
-            return
         sep = self._path._flavour.sep  # type:ignore
         bucket = self._client.lookup_bucket(self._path)
         if bucket is None:
